# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"Credentials": "00_core.ipynb",
         "get": "00_core.ipynb"}

modules = ["core.py"]

doc_url = "https://miklevin.github.io/ohawf/"

git_url = "https://github.com/miklevin/ohawf/tree/main/"

def custom_doc_links(name): return None
